Module codegen

Module codegen 

Available on crate feature macros only.
Helper type-level glue for cucumber_codegen crate.

Re-exports

pub use anyhow;
pub use inventory;

Macros

collect
Associate a plugin registry with the specified type.
submit
Enter an element into the plugin registry corresponding to its type.

Structs

Expression
Top-level expression defined in the grammar spec.
Regex
A compiled regular expression for searching Unicode haystacks.

Traits

IntoWorldResult
Return-type polymorphism over fallibility for a #[world(init)] attribute of a #[derive(World)] macro.
Parameter
Custom parameter of a Cucumber Expression.
ParametersProvider
Provider of custom Parameters.
StepConstructor
Trait for registering a Step with given, when and then attributes inside World::collection() method.
ToWorldFuture
Return-type polymorphism over asyncness for a #[world(init)] attribute of a #[derive(World)] macro.
WorldInventory
World extension allowing to register steps in inventory.

Functions

str_eq
Compares two strings in a const context.

Type Aliases

LazyRegex
Alias for a fn returning a Regex.
LocalBoxFuturealloc
BoxFuture, but without the Send requirement.
Spanned
str along with its location information in the original input.