pub struct Basic<World, F = WhichScenarioFn, Before = BeforeHookFn<World>, After = AfterHookFn<World>> { /* private fields */ }Expand description
Default Runner implementation which follows order guarantees from
the Runner trait docs.
Executes Scenarios concurrently based on the custom function, which
returns ScenarioType. Also, can limit maximum number of concurrent
Scenarios.
Implementations
Sourceimpl<World, Which, Before, After> Basic<World, Which, Before, After>
impl<World, Which, Before, After> Basic<World, Which, Before, After>
Sourcepub fn max_concurrent_scenarios(self, max: impl Into<Option<usize>>) -> Self
pub fn max_concurrent_scenarios(self, max: impl Into<Option<usize>>) -> Self
Sourcepub fn retry_after(self, after: impl Into<Option<Duration>>) -> Self
pub fn retry_after(self, after: impl Into<Option<Duration>>) -> Self
Sourcepub fn retry_filter(
self,
tag_expression: impl Into<Option<TagOperation>>,
) -> Self
pub fn retry_filter( self, tag_expression: impl Into<Option<TagOperation>>, ) -> Self
Sourcepub fn which_scenario<F>(self, func: F) -> Basic<World, F, Before, After>
pub fn which_scenario<F>(self, func: F) -> Basic<World, F, Before, After>
Function determining whether a Scenario is Concurrent or
a Serial one.
Sourcepub fn retry_options<R>(self, func: R) -> Self
pub fn retry_options<R>(self, func: R) -> Self
Function determining Scenario’s RetryOptions.
Sourcepub fn before<Func>(self, func: Func) -> Basic<World, Which, Func, After>where
Func: for<'a> Fn(&'a Feature, Option<&'a Rule>, &'a Scenario, &'a mut World) -> LocalBoxFuture<'a, ()>,
pub fn before<Func>(self, func: Func) -> Basic<World, Which, Func, After>where
Func: for<'a> Fn(&'a Feature, Option<&'a Rule>, &'a Scenario, &'a mut World) -> LocalBoxFuture<'a, ()>,
Sets a hook, executed on each Scenario before running all its
Steps, including Background ones.
Sourcepub fn after<Func>(self, func: Func) -> Basic<World, Which, Before, Func>where
Func: for<'a> Fn(&'a Feature, Option<&'a Rule>, &'a Scenario, &'a ScenarioFinished, Option<&'a mut World>) -> LocalBoxFuture<'a, ()>,
pub fn after<Func>(self, func: Func) -> Basic<World, Which, Before, Func>where
Func: for<'a> Fn(&'a Feature, Option<&'a Rule>, &'a Scenario, &'a ScenarioFinished, Option<&'a mut World>) -> LocalBoxFuture<'a, ()>,
Sourcepub fn steps(self, steps: Collection<World>) -> Self
pub fn steps(self, steps: Collection<World>) -> Self
Sets the given Collection of Steps to this Runner.