Element

Struct Element 

pub struct Element {
    pub after: Vec<HookResult>,
    pub before: Vec<HookResult>,
    pub keyword: String,
    pub type: &'static str,
    pub id: String,
    pub line: usize,
    pub name: String,
    pub tags: Vec<Tag>,
    pub steps: Vec<Step>,
}
Available on crate feature output-json only.
Fields

after: Vec<HookResult>

Doesn’t appear in the JSON schema, but present in its generated test cases.

before: Vec<HookResult>

Doesn’t appear in the JSON schema, but present in its generated test cases.

keyword: Stringtype: &'static str

Type of this Element.

Only set to background or scenario, but JSON schema doesn’t constraint only to those values, so maybe a subject to change.

id: String

Identifier of this Element. Doesn’t have to be unique.

line: usize

gherkin::Scenario line number inside a .feature file.

name: String

gherkin::Scenario::name, optionally prepended with a gherkin::Rule::name.

This is done because JSON schema doesn’t support gherkin::Rules at the moment.

tags: Vec<Tag>steps: Vec<Step>