pub struct AssertNormalized<W: ?Sized>(/* private fields */);Expand description
Wrapper for a Writer asserting it being Normalized.
Technically is no-op, only forcing the Writer to become Normalized
despite it actually doesn’t represent the one.
⚠️ WARNING: Should be used only in case you are absolutely sure, that incoming events will be emitted in a
Normalizedorder. For example, in casemax_concurrent_scenarios()is set to1.
Implementations
Sourceimpl<Writer> AssertNormalized<Writer>
impl<Writer> AssertNormalized<Writer>
Sourcepub const fn new(writer: Writer) -> Self
pub const fn new(writer: Writer) -> Self
Creates a new no-op AssertNormalized wrapper forcing Normalized
implementation.
⚠️ WARNING: Should be used only in case you are absolutely sure, that incoming events will be emitted in a
Normalizedorder. For example, in casemax_concurrent_scenarios()is set to1.