pub struct Normalize<World, Writer> { /* private fields */ }Expand description
Wrapper for a Writer implementation for outputting events corresponding
to order guarantees from the Runner in a Normalized readable
order.
Doesn’t output anything by itself, but rather is used as a combinator for
rearranging events and feeding them to the underlying Writer.
If some Feature has started to be
written into an output, then it will be written uninterruptedly until its
end, even if some other Features have finished their execution. It makes
much easier to understand what is really happening in the running
Feature while don’t impose any restrictions on the running order.
Implementations
Sourceimpl<W, Writer> Normalize<W, Writer>
impl<W, Writer> Normalize<W, Writer>
Sourcepub fn new(writer: Writer) -> Self
pub fn new(writer: Writer) -> Self
Creates a new Normalized wrapper, which will rearrange events
and feed them to the given Writer.
Sourcepub const fn inner_writer(&self) -> &Writer
pub const fn inner_writer(&self) -> &Writer
Returns the original Writer, wrapped by this Normalized one.